@@ -1,8 +1,5 @@
 package HTTP::Body::MultiPart;
-{
-  $HTTP::Body::MultiPart::VERSION = '1.19';
-}
-
+$HTTP::Body::MultiPart::VERSION = '1.20';
 use strict;
 use base 'HTTP::Body';
 use bytes;
@@ -303,8 +300,11 @@ sub handler {
                 $self->upload( $part->{name}, $part );
             }
         }
+        # If we have more than the content-disposition, we need to create a
+        # data key so that we don't waste the headers.
         else {
             $self->param( $part->{name}, $part->{data} );
+            $self->part_data( $part->{name}, $part )
         }
     }
 }
